@@ -1,11 +1,6 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
 
-
-import sys
-import os
-sys.path.append(os.path.dirname(__file__))
-
 from typing import List
 from .javalang.tokenizer import JavaToken
 
